@@ -260,7 +260,7 @@ def h_to_y(h_parameters):
     return(z_to_h(r1))
 
 
-def plot_circle_dia(Voc,Ioc,Woc,Vsc,Isc,Wsc,Rating,Rotor_to_stator_loss_ratio,Scale,save_path):
+def plot_circle_dia(Voc,Ioc,Woc,Vsc,Isc,Wsc,Rating,Rotor_to_stator_loss_ratio,Scale,save_path, show_plot):
     iocs = Ioc/Scale
     iscs = Isc/Scale
     
@@ -387,8 +387,10 @@ def plot_circle_dia(Voc,Ioc,Woc,Vsc,Isc,Wsc,Rating,Rotor_to_stator_loss_ratio,Sc
 
     if (save_path!=None):
         plt.savefig(save_path)
+    if(show_plot):
+        plt.show()
 
-    plt.show()
+    
 
     res = [maxt,moxo,fulli,maxi,efficency,powerfactor,startingtorque,torqueFullLoad]
     return res
